@@ -181,7 +181,7 @@ class TestGracedb(unittest.TestCase):
         cwb_event = r.json()
         self.assertEqual(cwb_event['group'], "Test")
         self.assertEqual(cwb_event['pipeline'], "CWB")
-        self.assertEqual(cwb_event['gpstime'], 1042312876)
+        self.assertEqual(float(cwb_event['gpstime']), 1042312876.5090)
 
     def test_create_lowmass(self):
         """Create a Low Mass event"""
@@ -191,14 +191,14 @@ class TestGracedb(unittest.TestCase):
 
     def test_create_mbta(self):
         """Create an MBTA event"""
-        """cbc-mbta.gwf"""
-        eventFile = os.path.join(testdatadir, "cbc-mbta.gwf")
+        """cbc-mbta.xml"""
+        eventFile = os.path.join(testdatadir, "cbc-mbta.xml")
         mbta_event = gracedb.createEvent(
                 "Test", "MBTAOnline", eventFile).json()
         self.assertEqual(mbta_event['group'], "Test")
         self.assertEqual(mbta_event['pipeline'], "MBTAOnline")
-        self.assertEqual(mbta_event['gpstime'], 1011992635)
-        self.assertEqual(mbta_event['far'], 0.000245980441198379)
+        self.assertEqual(float(mbta_event['gpstime']), 1078903329.421037)
+        self.assertEqual(mbta_event['far'], 4.006953918826065e-7)
 
     def test_replace_event(self):
         graceid = eventId
@@ -206,7 +206,7 @@ class TestGracedb(unittest.TestCase):
         old_event = gracedb.event(graceid).json()
         self.assertEqual(old_event['group'], "Test")
         self.assertEqual(old_event['search'], "LowMass")
-        self.assertEqual(old_event['gpstime'], 971609248)
+        self.assertEqual(float(old_event['gpstime']), 971609248.151741)
 
         replacementFile = os.path.join(testdatadir, "cbc-lm2.xml")
 
@@ -216,7 +216,7 @@ class TestGracedb(unittest.TestCase):
         new_event = gracedb.event(graceid).json()
         self.assertEqual(new_event['group'], "Test")
         self.assertEqual(new_event['search'], "LowMass")
-        self.assertEqual(new_event['gpstime'], 971609249)
+        self.assertEqual(float(new_event['gpstime']), 971609249.151741)
 
     def test_upload_binary(self):
         """
@@ -270,11 +270,14 @@ class TestGracedb(unittest.TestCase):
     def test_gittag(self):
         # try to make sure GIT_TAG is set properly.
         import errno
-        version = "1.15"
+        version = "1.17"
         try:
             # If we are in the source dir (setup.py is available)
             # make sure the version above agrees.
-            setup_file = open("setup.py", 'r')
+            if os.path.exists("setup.py"):
+                setup_file = open("setup.py", 'r')
+            else:
+                setup_file = open("../../../setup.py", 'r')
             v = ""
             for line in setup_file:
                 if line.startswith("version"):
